.. _synthetic_radiography:

**************************************
Synthetic Charged Particle Radiography
**************************************
.. currentmodule:: plasmapy.diagnostics.charged_particle_radiography.synthetic_radiography

.. automodapi:: plasmapy.diagnostics.charged_particle_radiography.synthetic_radiography

.. nbgallery::
    :caption: Examples

    /notebooks/diagnostics/charged_particle_radiography_particle_tracing
    /notebooks/diagnostics/charged_particle_radiography_particle_tracing_custom_source
    /notebooks/diagnostics/charged_particle_radiography_particle_tracing_wire_mesh
